<a id="autonomy.chain.constants"></a>

# autonomy.chain.constants

Chain constants

<a id="autonomy.chain.constants.CONTRACTS_DIR_LOCAL"></a>

#### CONTRACTS`_`DIR`_`LOCAL

use from an editable/local installation

